==> guikachu-0.12.tar.gz: guikachu-0.12/src/add-resource.cc <==
//$Id: add-resource.cc,v 1.8 2001/10/19 20:17:55 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "add-resource.h"

#include "config.h"
#include <libgnome/libgnome.h>

#include <gtk--/optionmenu.h>
#include <gtk--/menu.h>

#include "resource-manager.h"

using namespace Guikachu;

GUI::AddResourceWin::AddResourceWin ()
{
    gui = glade_xml_new (GLADEDIR "/guikachu.glade", 0);

    Gtk::OptionMenu *optmenu;
    Gtk::Menu       *menu;
    
    dialog = Gtk::wrap (GNOME_DIALOG (glade_xml_get_widget (gui, "dlg_add")));
    optmenu = Gtk::wrap (GTK_OPTION_MENU (glade_xml_get_widget (gui, "add_type")));
    entry = Gtk::wrap (GTK_ENTRY (glade_xml_get_widget (gui, "add_name")));

    menu = optmenu->get_menu ();
    menu->items ().clear ();
    menu->items ().push_back (Gtk::Menu_Helpers::MenuElem
			      (_("Form"),
			       SigC::bind (
				   SigC::slot (this, &AddResourceWin::resource_type_cb),
				   Resources::RESOURCE_FORM)));
    menu->items ().push_back (Gtk::Menu_Helpers::MenuElem
			      (_("Dialog"),
			       SigC::bind (
				   SigC::slot (this, &AddResourceWin::resource_type_cb),
				   Resources::RESOURCE_DIALOG)));
    menu->items ().push_back (Gtk::Menu_Helpers::MenuElem
			      (_("Menu"),
			       SigC::bind (
				   SigC::slot (this, &AddResourceWin::resource_type_cb),
				   Resources::RESOURCE_MENU)));
    menu->items ().push_back (Gtk::Menu_Helpers::MenuElem
			      (_("String"),
			       SigC::bind (
				   SigC::slot (this, &AddResourceWin::resource_type_cb),
				   Resources::RESOURCE_STRING)));
    menu->items ().push_back (Gtk::Menu_Helpers::MenuElem
			      (_("Free-text blob"),
			       SigC::bind (
				   SigC::slot (this, &AddResourceWin::resource_type_cb),
				   Resources::RESOURCE_BLOB)));

    optmenu->set_history (0);
    res_type = Resources::RESOURCE_FORM;

    dialog->editable_enters (*entry);
    dialog->close_hides (true);
}

GUI::AddResourceWin::~AddResourceWin ()
{
//    dialog->destroy ();
    gtk_widget_destroy (GTK_WIDGET (dialog->gtkobj ()));
    gtk_object_unref (GTK_OBJECT (gui));
}

void GUI::AddResourceWin::run ()
{
    int dialog_result;

    dialog_result = dialog->run_and_close ();

    if (dialog_result != -1)
    {
	if (dialog_result == 0)
	    ResourceManager::create_resource (res_type, entry->get_text ());
    }
}

void GUI::AddResourceWin::resource_type_cb (Resources::Type type)
{
    res_type = type;
}

==> guikachu_1.0.1.orig.tar.gz: guikachu-1.0.1/src/add-resource.cc <==
//$Id: add-resource.cc,v 1.9 2001/11/18 10:59:50 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "add-resource.h"

#include "config.h"
#include <libgnome/libgnome.h>

#include <gtk--/optionmenu.h>
#include <gtk--/menu.h>

#include "resource-manager.h"

using namespace Guikachu;

GUI::AddResourceWin::AddResourceWin ()
{
    gui = glade_xml_new (GLADEDIR "/guikachu.glade", "dlg_add");

    Gtk::OptionMenu *optmenu;
    Gtk::Menu       *menu;
    
    dialog = Gtk::wrap (GNOME_DIALOG (glade_xml_get_widget (gui, "dlg_add")));
    optmenu = Gtk::wrap (GTK_OPTION_MENU (glade_xml_get_widget (gui, "add_type")));
    entry = Gtk::wrap (GTK_ENTRY (glade_xml_get_widget (gui, "add_name")));

    menu = optmenu->get_menu ();
    menu->items ().clear ();
    menu->items ().push_back (Gtk::Menu_Helpers::MenuElem
			      (_("Form"),
			       SigC::bind (
				   SigC::slot (this, &AddResourceWin::resource_type_cb),
				   Resources::RESOURCE_FORM)));
    menu->items ().push_back (Gtk::Menu_Helpers::MenuElem
			      (_("Dialog"),
			       SigC::bind (
				   SigC::slot (this, &AddResourceWin::resource_type_cb),
				   Resources::RESOURCE_DIALOG)));
    menu->items ().push_back (Gtk::Menu_Helpers::MenuElem
			      (_("Menu"),
			       SigC::bind (
				   SigC::slot (this, &AddResourceWin::resource_type_cb),
				   Resources::RESOURCE_MENU)));
    menu->items ().push_back (Gtk::Menu_Helpers::MenuElem
			      (_("String"),
			       SigC::bind (
				   SigC::slot (this, &AddResourceWin::resource_type_cb),
				   Resources::RESOURCE_STRING)));
    menu->items ().push_back (Gtk::Menu_Helpers::MenuElem
			      (_("Free-text blob"),
			       SigC::bind (
				   SigC::slot (this, &AddResourceWin::resource_type_cb),
				   Resources::RESOURCE_BLOB)));

    optmenu->set_history (0);
    res_type = Resources::RESOURCE_FORM;

    dialog->editable_enters (*entry);
    dialog->close_hides (true);
}

GUI::AddResourceWin::~AddResourceWin ()
{
//    dialog->destroy ();
    gtk_widget_destroy (GTK_WIDGET (dialog->gtkobj ()));
    gtk_object_unref (GTK_OBJECT (gui));
}

void GUI::AddResourceWin::run ()
{
    int dialog_result;

    dialog_result = dialog->run_and_close ();

    if (dialog_result != -1)
    {
	if (dialog_result == 0)
	    ResourceManager::create_resource (res_type, entry->get_text ());
    }
}

void GUI::AddResourceWin::resource_type_cb (Resources::Type type)
{
    res_type = type;
}
